@@ -578,7 +578,7 @@ if (true) loop: for(let _i = 0, _iter = []; _i < _iter.length; _i++){
 "#
 );
 
-#[testing::fixture("tests/fixture/for-of/**/exec.js")]
+#[testing::fixture("tests/for-of/**/exec.js")]
 fn fixture(input: PathBuf) {
     let input = read_to_string(&input).unwrap();
 
@@ -598,7 +598,7 @@ fn fixture(input: PathBuf) {
     );
 }
 
-#[testing::fixture("tests/fixture/for-of/**/exec.js")]
+#[testing::fixture("tests/for-of/**/exec.js")]
 fn fixture_es2015(input: PathBuf) {
     let input = read_to_string(&input).unwrap();
 
