@@ -1,4 +1,4 @@
-var _foo = new WeakMap(), _bar = new WeakMap();
+var _foo = /*#__PURE__*/ new WeakMap(), _bar = /*#__PURE__*/ new WeakMap();
 let Foo = /*#__PURE__*/ function() {
     "use strict";
     function Foo() {
@@ -16,7 +16,7 @@ let Foo = /*#__PURE__*/ function() {
         {
             key: "test",
             value: function test() {
-                var _bar1 = new WeakMap();
+                var _bar1 = /*#__PURE__*/ new WeakMap();
                 let Nested = /*#__PURE__*/ function() {
                     function Nested() {
                         _classCallCheck(this, Nested);
